@@ -55,7 +55,7 @@ TESSERACT_COMMON_IGNORE_WARNINGS_PUSH
 #include <console_bridge/console.h>
 
 #include <tesseract_common/types.h>
-#include <tesseract_common/resource.h>
+#include <tesseract_common/resource_locator.h>
 
 #include <regex>
 #include <boost/filesystem/path.hpp>
@@ -83,6 +83,7 @@ std::vector<std::shared_ptr<T>> extractMeshData(const aiScene* scene,
                                                 bool material_and_texture)
 {
   std::vector<std::shared_ptr<T>> meshes;
+  meshes.reserve(node->mNumMeshes);
 
   aiMatrix4x4 transform = parent_transform;
   transform *= node->mTransformation;
@@ -96,6 +97,7 @@ std::vector<std::shared_ptr<T>> extractMeshData(const aiScene* scene,
     std::shared_ptr<std::vector<MeshTexture::Ptr>> textures = nullptr;
 
     const aiMesh* a = scene->mMeshes[node->mMeshes[j]];
+    vertices->reserve(a->mNumVertices);
     for (unsigned int i = 0; i < a->mNumVertices; ++i)
     {
       aiVector3D v = transform * a->mVertices[i];
@@ -118,7 +120,7 @@ std::vector<std::shared_ptr<T>> extractMeshData(const aiScene* scene,
       }
       else
       {
-        CONSOLE_BRIDGE_logDebug("Mesh had a face with less than three verticies: %s", resource->getUrl().c_str());
+        CONSOLE_BRIDGE_logDebug("Mesh had a face with less than three vertices: %s", resource->getUrl().c_str());
       }
     }
 
@@ -129,6 +131,7 @@ std::vector<std::shared_ptr<T>> extractMeshData(const aiScene* scene,
     if (normals && a->HasNormals())
     {
       vertex_normals = std::make_shared<tesseract_common::VectorVector3d>();
+      vertex_normals->reserve(a->mNumVertices);
       for (unsigned int i = 0; i < a->mNumVertices; ++i)
       {
         aiVector3D v = transform * a->mNormals[i];
@@ -141,6 +144,7 @@ std::vector<std::shared_ptr<T>> extractMeshData(const aiScene* scene,
     if (vertex_colors && a->HasVertexColors(0))
     {
       vertex_colors = std::make_shared<tesseract_common::VectorVector4d>();
+      vertex_colors->reserve(a->mNumVertices);
       for (unsigned int i = 0; i < a->mNumVertices; ++i)
       {
         aiColor4D v = a->mColors[0][i];
@@ -164,12 +168,12 @@ std::vector<std::shared_ptr<T>> extractMeshData(const aiScene* scene,
         {
           // Use PBR Metallic material properties if available
           base_color = Eigen::Vector4d(pbr_base_color.r, pbr_base_color.g, pbr_base_color.b, pbr_base_color.a);
-          float metallicFactor;
+          float metallicFactor{ 0 };
           if (mat->Get(AI_MATKEY_GLTF_PBRMETALLICROUGHNESS_METALLIC_FACTOR, metallicFactor) == AI_SUCCESS)
           {
             metallic = metallicFactor;
           }
-          float roughnessFactor;
+          float roughnessFactor{ 0.5 };
           if (mat->Get(AI_MATKEY_GLTF_PBRMETALLICROUGHNESS_ROUGHNESS_FACTOR, roughnessFactor) == AI_SUCCESS)
           {
             roughness = roughnessFactor;
@@ -205,8 +209,8 @@ std::vector<std::shared_ptr<T>> extractMeshData(const aiScene* scene,
           if (a->HasTextureCoords(i))
           {
             aiString texName;
-            aiTextureMapping mapping;
-            unsigned int uvIndex;
+            aiTextureMapping mapping{ aiTextureMapping_OTHER };
+            unsigned int uvIndex{ 0 };
             if (mat->GetTexture(aiTextureType_DIFFUSE, i, &texName, &mapping, &uvIndex) == AI_SUCCESS)
             {
               tesseract_common::Resource::Ptr texture_image;
@@ -218,13 +222,13 @@ std::vector<std::shared_ptr<T>> extractMeshData(const aiScene* scene,
                 int tex_index = std::atoi(texNamec + 1);
                 if (0 > tex_index || scene->mNumTextures <= static_cast<unsigned>(tex_index))
                   continue;
-                auto texture_data = scene->mTextures[tex_index];
+                auto* texture_data = scene->mTextures[tex_index];
                 // returned pointer is not null, read texture from memory
                 std::string file_type = texture_data->achFormatHint;
                 if (file_type == "jpg" || file_type == "png")
                 {
                   texture_image = std::make_shared<tesseract_common::BytesResource>(
-                      "data://", (const uint8_t*)texture_data->pcData, texture_data->mWidth);
+                      "data://", (const uint8_t*)texture_data->pcData, texture_data->mWidth);  // NOLINT
                 }
                 else
                 {
@@ -239,7 +243,7 @@ std::vector<std::shared_ptr<T>> extractMeshData(const aiScene* scene,
                   continue;
                 }
                 std::string texName_str(texName.C_Str());
-                auto tex_resource = resource->locateSubResource(texName_str);
+                auto tex_resource = resource->locateResource(texName_str);
                 if (!tex_resource)
                 {
                   continue;
@@ -323,7 +327,7 @@ std::vector<std::shared_ptr<T>> createMeshFromAsset(const aiScene* scene,
  * @brief Create a mesh using assimp from file path
  * @param path The file path to the mesh
  * @param scale Perform an axis scaling
- * @param trianglulate If true the mesh will be trianglulated. This should be done for visual meshes.
+ * @param triangulate If true the mesh will be triangulated. This should be done for visual meshes.
  *        In the case of collision meshes do not triangulate convex hull meshes.
  * @param flatten If true all meshes will be condensed into a single mesh. This should only be used for visual meshes,
  * do not flatten collision meshes.
@@ -380,7 +384,7 @@ std::vector<std::shared_ptr<T>> createMeshFromPath(const std::string& path,
   }
 
   // Assimp enforces Y_UP convention by rotating models with different conventions.
-  // However, that behaviour is confusing and doesn't match the ROS convention
+  // However, that behavior is confusing and doesn't match the ROS convention
   // where the Z axis is pointing up.
   // Hopefully this doesn't undo legit use of the root node transformation...
   // Note that this is also what RViz does internally.
@@ -405,7 +409,7 @@ std::vector<std::shared_ptr<T>> createMeshFromPath(const std::string& path,
  * @brief Create a mesh using assimp from resource
  * @param resource The located resource
  * @param scale Perform an axis scaling
- * @param trianglulate If true the mesh will be trianglulated. This should be done for visual meshes.
+ * @param triangulate If true the mesh will be triangulated. This should be done for visual meshes.
  *        In the case of collision meshes do not triangulate convex hull meshes.
  * @param flatten If true all meshes will be condensed into a single mesh. This should only be used for visual meshes,
  * do not flatten collision meshes.
@@ -476,14 +480,14 @@ std::vector<std::shared_ptr<T>> createMeshFromResource(tesseract_common::Resourc
   // And have it read the given file with some post-processing
   const aiScene* scene = nullptr;
   if (triangulate)
-    scene = importer.ReadFileFromMemory(&data[0],
+    scene = importer.ReadFileFromMemory(data.data(),
                                         data.size(),
                                         aiProcess_Triangulate | aiProcess_JoinIdenticalVertices |
                                             aiProcess_SortByPType | aiProcess_RemoveComponent,
                                         hint);
   else
     scene =
-        importer.ReadFileFromMemory(&data[0],
+        importer.ReadFileFromMemory(data.data(),
                                     data.size(),
                                     aiProcess_JoinIdenticalVertices | aiProcess_SortByPType | aiProcess_RemoveComponent,
                                     hint);
@@ -496,7 +500,7 @@ std::vector<std::shared_ptr<T>> createMeshFromResource(tesseract_common::Resourc
   }
 
   // Assimp enforces Y_UP convention by rotating models with different conventions.
-  // However, that behaviour is confusing and doesn't match the ROS convention
+  // However, that behavior is confusing and doesn't match the ROS convention
   // where the Z axis is pointing up.
   // Hopefully this doesn't undo legit use of the root node transformation...
   // Note that this is also what RViz does internally.
@@ -522,7 +526,7 @@ std::vector<std::shared_ptr<T>> createMeshFromResource(tesseract_common::Resourc
  * @param bytes Byte array
  * @param bytes_len The length of bytes
  * @param scale Perform an axis scaling
- * @param trianglulate If true the mesh will be trianglulated. This should be done for visual meshes.
+ * @param triangulate If true the mesh will be triangulated. This should be done for visual meshes.
  *        In the case of collision meshes do not triangulate convex hull meshes.
  * @param flatten If true all meshes will be condensed into a single mesh. This should only be used for visual meshes,
  * do not flatten collision meshes.
@@ -550,17 +554,4 @@ static std::vector<std::shared_ptr<T>> createMeshFromBytes(const std::string& ur
 
 }  // namespace tesseract_geometry
 
-#ifdef SWIG
-%pybuffer_binary(const uint8_t* bytes, size_t bytes_len);
-%template(createMeshFromResource) tesseract_geometry::createMeshFromResource<tesseract_geometry::Mesh>;
-%template(createSDFMeshFromResource) tesseract_geometry::createMeshFromResource<tesseract_geometry::SDFMesh>;
-%template(createConvexMeshFromResource) tesseract_geometry::createMeshFromResource<tesseract_geometry::ConvexMesh>;
-%template(createMeshFromPath) tesseract_geometry::createMeshFromPath<tesseract_geometry::Mesh>;
-%template(createSDFMeshFromPath) tesseract_geometry::createMeshFromPath<tesseract_geometry::SDFMesh>;
-%template(createConvexMeshFromPath) tesseract_geometry::createMeshFromPath<tesseract_geometry::ConvexMesh>;
-%template(createMeshFromBytes) tesseract_geometry::createMeshFromBytes<tesseract_geometry::Mesh>;
-%template(createSDFMeshFromBytes) tesseract_geometry::createMeshFromBytes<tesseract_geometry::SDFMesh>;
-%template(createConvexMeshFromBytes) tesseract_geometry::createMeshFromBytes<tesseract_geometry::ConvexMesh>;
-#endif
-
 #endif
