@@ -8,6 +8,7 @@ TESSERACT_COMMON_IGNORE_WARNINGS_POP
 
 #include <tesseract_geometry/geometries.h>
 #include <tesseract_geometry/mesh_parser.h>
+#include <tesseract_geometry/utils.h>
 
 TEST(TesseractGeometryUnit, Instantiation)  // NOLINT
 {
@@ -52,11 +53,20 @@ TEST(TesseractGeometryUnit, Box)  // NOLINT
   EXPECT_NEAR(geom->getX(), 1, 1e-5);
   EXPECT_NEAR(geom->getY(), 1, 1e-5);
   EXPECT_NEAR(geom->getZ(), 1, 1e-5);
+  EXPECT_EQ(geom->getType(), tesseract_geometry::GeometryType::BOX);
 
   auto geom_clone = geom->clone();
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getX(), 1, 1e-5);
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getY(), 1, 1e-5);
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getZ(), 1, 1e-5);
+  EXPECT_EQ(geom_clone->getType(), tesseract_geometry::GeometryType::BOX);
+
+  // Test isIdentical
+  EXPECT_TRUE(tesseract_geometry::isIdentical(*geom, *geom_clone));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Box(2, 1, 1)));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Box(1, 2, 1)));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Box(1, 1, 2)));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Cone(1, 1)));
 }
 
 TEST(TesseractGeometryUnit, Cone)  // NOLINT
@@ -65,10 +75,17 @@ TEST(TesseractGeometryUnit, Cone)  // NOLINT
   auto geom = std::make_shared<T>(1, 1);
   EXPECT_NEAR(geom->getRadius(), 1, 1e-5);
   EXPECT_NEAR(geom->getLength(), 1, 1e-5);
+  EXPECT_EQ(geom->getType(), tesseract_geometry::GeometryType::CONE);
 
   auto geom_clone = geom->clone();
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getRadius(), 1, 1e-5);
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getLength(), 1, 1e-5);
+  EXPECT_EQ(geom_clone->getType(), tesseract_geometry::GeometryType::CONE);
+
+  // Test isIdentical
+  EXPECT_TRUE(tesseract_geometry::isIdentical(*geom, *geom_clone));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Cone(2, 1)));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Cone(1, 2)));
 }
 
 TEST(TesseractGeometryUnit, Cylinder)  // NOLINT
@@ -77,10 +94,17 @@ TEST(TesseractGeometryUnit, Cylinder)  // NOLINT
   auto geom = std::make_shared<T>(1, 1);
   EXPECT_NEAR(geom->getRadius(), 1, 1e-5);
   EXPECT_NEAR(geom->getLength(), 1, 1e-5);
+  EXPECT_EQ(geom->getType(), tesseract_geometry::GeometryType::CYLINDER);
 
   auto geom_clone = geom->clone();
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getRadius(), 1, 1e-5);
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getLength(), 1, 1e-5);
+  EXPECT_EQ(geom_clone->getType(), tesseract_geometry::GeometryType::CYLINDER);
+
+  // Test isIdentical
+  EXPECT_TRUE(tesseract_geometry::isIdentical(*geom, *geom_clone));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Cylinder(2, 1)));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Cylinder(1, 2)));
 }
 
 TEST(TesseractGeometryUnit, Capsule)  // NOLINT
@@ -89,10 +113,17 @@ TEST(TesseractGeometryUnit, Capsule)  // NOLINT
   auto geom = std::make_shared<T>(1, 1);
   EXPECT_NEAR(geom->getRadius(), 1, 1e-5);
   EXPECT_NEAR(geom->getLength(), 1, 1e-5);
+  EXPECT_EQ(geom->getType(), tesseract_geometry::GeometryType::CAPSULE);
 
   auto geom_clone = geom->clone();
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getRadius(), 1, 1e-5);
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getLength(), 1, 1e-5);
+  EXPECT_EQ(geom_clone->getType(), tesseract_geometry::GeometryType::CAPSULE);
+
+  // Test isIdentical
+  EXPECT_TRUE(tesseract_geometry::isIdentical(*geom, *geom_clone));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Capsule(2, 1)));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Capsule(1, 2)));
 }
 
 TEST(TesseractGeometryUnit, Sphere)  // NOLINT
@@ -100,9 +131,15 @@ TEST(TesseractGeometryUnit, Sphere)  // NOLINT
   using T = tesseract_geometry::Sphere;
   auto geom = std::make_shared<T>(1);
   EXPECT_NEAR(geom->getRadius(), 1, 1e-5);
+  EXPECT_EQ(geom->getType(), tesseract_geometry::GeometryType::SPHERE);
 
   auto geom_clone = geom->clone();
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getRadius(), 1, 1e-5);
+  EXPECT_EQ(geom_clone->getType(), tesseract_geometry::GeometryType::SPHERE);
+
+  // Test isIdentical
+  EXPECT_TRUE(tesseract_geometry::isIdentical(*geom, *geom_clone));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Sphere(2)));
 }
 
 TEST(TesseractGeometryUnit, Plane)  // NOLINT
@@ -113,12 +150,60 @@ TEST(TesseractGeometryUnit, Plane)  // NOLINT
   EXPECT_NEAR(geom->getB(), 1, 1e-5);
   EXPECT_NEAR(geom->getC(), 1, 1e-5);
   EXPECT_NEAR(geom->getD(), 1, 1e-5);
+  EXPECT_EQ(geom->getType(), tesseract_geometry::GeometryType::PLANE);
 
   auto geom_clone = geom->clone();
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getA(), 1, 1e-5);
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getB(), 1, 1e-5);
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getC(), 1, 1e-5);
   EXPECT_NEAR(std::static_pointer_cast<T>(geom_clone)->getD(), 1, 1e-5);
+  EXPECT_EQ(geom_clone->getType(), tesseract_geometry::GeometryType::PLANE);
+
+  // Test isIdentical
+  EXPECT_TRUE(tesseract_geometry::isIdentical(*geom, *geom_clone));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Plane(2, 1, 1, 1)));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Plane(1, 2, 1, 1)));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Plane(1, 1, 2, 1)));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(*geom, tesseract_geometry::Plane(1, 1, 1, 2)));
+}
+
+TEST(TesseractGeometryUnit, PolygonMesh)  // NOLINT
+{
+  auto vertices = std::make_shared<tesseract_common::VectorVector3d>();
+  vertices->emplace_back(1, 1, 0);
+  vertices->emplace_back(1, -1, 0);
+  vertices->emplace_back(-1, -1, 0);
+  vertices->emplace_back(1, -1, 0);
+
+  auto faces = std::make_shared<Eigen::VectorXi>();
+  faces->resize(5);
+  (*faces)(0) = 4;
+  (*faces)(1) = 0;
+  (*faces)(2) = 1;
+  (*faces)(3) = 2;
+  (*faces)(4) = 3;
+
+  using T = tesseract_geometry::PolygonMesh;
+  auto geom = std::make_shared<T>(vertices, faces);
+  EXPECT_TRUE(geom->getVertices() != nullptr);
+  EXPECT_TRUE(geom->getFaces() != nullptr);
+  EXPECT_TRUE(geom->getVertexCount() == 4);
+  EXPECT_TRUE(geom->getFaceCount() == 1);
+  EXPECT_EQ(geom->getType(), tesseract_geometry::GeometryType::POLYGON_MESH);
+
+  auto geom_clone = geom->clone();
+  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVertices() != nullptr);
+  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getFaces() != nullptr);
+  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVertexCount() == 4);
+  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getFaceCount() == 1);
+  EXPECT_EQ(geom_clone->getType(), tesseract_geometry::GeometryType::POLYGON_MESH);
+
+  // Test isIdentical
+  EXPECT_TRUE(tesseract_geometry::isIdentical(*geom, *geom_clone));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(
+      *geom,
+      tesseract_geometry::PolygonMesh(std::make_shared<tesseract_common::VectorVector3d>(),
+                                      std::make_shared<Eigen::VectorXi>())));
 }
 
 TEST(TesseractGeometryUnit, ConvexMesh)  // NOLINT
@@ -141,14 +226,23 @@ TEST(TesseractGeometryUnit, ConvexMesh)  // NOLINT
   auto geom = std::make_shared<T>(vertices, faces);
   EXPECT_TRUE(geom->getVertices() != nullptr);
   EXPECT_TRUE(geom->getFaces() != nullptr);
-  EXPECT_TRUE(geom->getVerticeCount() == 4);
+  EXPECT_TRUE(geom->getVertexCount() == 4);
   EXPECT_TRUE(geom->getFaceCount() == 1);
+  EXPECT_EQ(geom->getType(), tesseract_geometry::GeometryType::CONVEX_MESH);
 
   auto geom_clone = geom->clone();
   EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVertices() != nullptr);
   EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getFaces() != nullptr);
-  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVerticeCount() == 4);
+  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVertexCount() == 4);
   EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getFaceCount() == 1);
+  EXPECT_EQ(geom_clone->getType(), tesseract_geometry::GeometryType::CONVEX_MESH);
+
+  // Test isIdentical
+  EXPECT_TRUE(tesseract_geometry::isIdentical(*geom, *geom_clone));
+  EXPECT_FALSE(tesseract_geometry::isIdentical(
+      *geom,
+      tesseract_geometry::ConvexMesh(std::make_shared<tesseract_common::VectorVector3d>(),
+                                     std::make_shared<Eigen::VectorXi>())));
 }
 
 TEST(TesseractGeometryUnit, Mesh)  // NOLINT
@@ -172,17 +266,57 @@ TEST(TesseractGeometryUnit, Mesh)  // NOLINT
   (*faces)(7) = 3;
 
   using T = tesseract_geometry::Mesh;
-  auto geom = std::make_shared<T>(vertices, faces);
-  EXPECT_TRUE(geom->getVertices() != nullptr);
-  EXPECT_TRUE(geom->getTriangles() != nullptr);
-  EXPECT_TRUE(geom->getVerticeCount() == 4);
-  EXPECT_TRUE(geom->getTriangleCount() == 2);
 
-  auto geom_clone = geom->clone();
-  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVertices() != nullptr);
-  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getTriangles() != nullptr);
-  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVerticeCount() == 4);
-  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getTriangleCount() == 2);
+  {
+    auto geom = std::make_shared<T>(vertices, faces);
+    EXPECT_TRUE(geom->getVertices() != nullptr);
+    EXPECT_TRUE(geom->getFaces() != nullptr);
+    EXPECT_TRUE(geom->getVertexCount() == 4);
+    EXPECT_TRUE(geom->getFaceCount() == 2);
+    EXPECT_TRUE(geom->getMaterial() == nullptr);
+    EXPECT_EQ(geom->getType(), tesseract_geometry::GeometryType::MESH);
+
+    auto geom_clone = geom->clone();
+    EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVertices() != nullptr);
+    EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getFaces() != nullptr);
+    EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVertexCount() == 4);
+    EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getFaceCount() == 2);
+    EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getMaterial() == nullptr);
+    EXPECT_EQ(geom_clone->getType(), tesseract_geometry::GeometryType::MESH);
+
+    // Test isIdentical
+    EXPECT_TRUE(tesseract_geometry::isIdentical(*geom, *geom_clone));
+    EXPECT_FALSE(
+        tesseract_geometry::isIdentical(*geom,
+                                        tesseract_geometry::Mesh(std::make_shared<tesseract_common::VectorVector3d>(),
+                                                                 std::make_shared<Eigen::VectorXi>())));
+  }
+
+  {
+    auto mat = std::make_shared<tesseract_geometry::MeshMaterial>();
+    auto geom = std::make_shared<T>(vertices, faces, nullptr, Eigen::Vector3d(1, 1, 1), nullptr, nullptr, mat);
+    EXPECT_TRUE(geom->getVertices() != nullptr);
+    EXPECT_TRUE(geom->getFaces() != nullptr);
+    EXPECT_TRUE(geom->getVertexCount() == 4);
+    EXPECT_TRUE(geom->getFaceCount() == 2);
+    EXPECT_TRUE(geom->getMaterial() != nullptr);
+    EXPECT_EQ(geom->getType(), tesseract_geometry::GeometryType::MESH);
+
+    auto geom_clone = geom->clone();
+    EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVertices() != nullptr);
+    EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getFaces() != nullptr);
+    EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVertexCount() == 4);
+    EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getFaceCount() == 2);
+    EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getMaterial() != nullptr);
+    EXPECT_EQ(geom_clone->getType(), tesseract_geometry::GeometryType::MESH);
+
+    // Test isIdentical
+    EXPECT_TRUE(tesseract_geometry::isIdentical(*geom, *geom_clone));
+    EXPECT_FALSE(
+        tesseract_geometry::isIdentical(*geom,
+                                        tesseract_geometry::Mesh(std::make_shared<tesseract_common::VectorVector3d>(),
+                                                                 std::make_shared<Eigen::VectorXi>())));
+  }
 }
 
 TEST(TesseractGeometryUnit, SDFMesh)  // NOLINT
@@ -208,15 +342,24 @@ TEST(TesseractGeometryUnit, SDFMesh)  // NOLINT
   using T = tesseract_geometry::SDFMesh;
   auto geom = std::make_shared<T>(vertices, faces);
   EXPECT_TRUE(geom->getVertices() != nullptr);
-  EXPECT_TRUE(geom->getTriangles() != nullptr);
-  EXPECT_TRUE(geom->getVerticeCount() == 4);
-  EXPECT_TRUE(geom->getTriangleCount() == 2);
+  EXPECT_TRUE(geom->getFaces() != nullptr);
+  EXPECT_TRUE(geom->getVertexCount() == 4);
+  EXPECT_TRUE(geom->getFaceCount() == 2);
+  EXPECT_EQ(geom->getType(), tesseract_geometry::GeometryType::SDF_MESH);
 
   auto geom_clone = geom->clone();
   EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVertices() != nullptr);
-  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getTriangles() != nullptr);
-  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVerticeCount() == 4);
-  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getTriangleCount() == 2);
+  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getFaces() != nullptr);
+  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getVertexCount() == 4);
+  EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getFaceCount() == 2);
+  EXPECT_EQ(geom_clone->getType(), tesseract_geometry::GeometryType::SDF_MESH);
+
+  // Test isIdentical
+  EXPECT_TRUE(tesseract_geometry::isIdentical(*geom, *geom_clone));
+  EXPECT_FALSE(
+      tesseract_geometry::isIdentical(*geom,
+                                      tesseract_geometry::SDFMesh(std::make_shared<tesseract_common::VectorVector3d>(),
+                                                                  std::make_shared<Eigen::VectorXi>())));
 }
 
 TEST(TesseractGeometryUnit, Octree)  // NOLINT
@@ -240,10 +383,15 @@ TEST(TesseractGeometryUnit, Octree)  // NOLINT
   auto geom = std::make_shared<T>(pc, 0.01, tesseract_geometry::Octree::SubType::BOX, false);
   EXPECT_TRUE(geom->getOctree() != nullptr);
   EXPECT_TRUE(geom->getSubType() == tesseract_geometry::Octree::SubType::BOX);
+  EXPECT_EQ(geom->getType(), tesseract_geometry::GeometryType::OCTREE);
 
   auto geom_clone = geom->clone();
   EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getOctree() != nullptr);
   EXPECT_TRUE(std::static_pointer_cast<T>(geom_clone)->getSubType() == tesseract_geometry::Octree::SubType::BOX);
+  EXPECT_EQ(geom_clone->getType(), tesseract_geometry::GeometryType::OCTREE);
+
+  // Test isIdentical
+  EXPECT_TRUE(tesseract_geometry::isIdentical(*geom, *geom_clone));
 }
 
 TEST(TesseractGeometryUnit, LoadMeshUnit)  // NOLINT
@@ -253,47 +401,47 @@ TEST(TesseractGeometryUnit, LoadMeshUnit)  // NOLINT
   std::string mesh_file = std::string(TESSERACT_SUPPORT_DIR) + "/meshes/sphere_p25m.stl";
   std::vector<Mesh::Ptr> meshes = createMeshFromPath<Mesh>(mesh_file);
   EXPECT_TRUE(meshes.size() == 1);
-  EXPECT_TRUE(meshes[0]->getTriangleCount() == 80);
-  EXPECT_TRUE(meshes[0]->getVerticeCount() == 42);
+  EXPECT_TRUE(meshes[0]->getFaceCount() == 80);
+  EXPECT_TRUE(meshes[0]->getVertexCount() == 42);
 
   mesh_file = std::string(TESSERACT_SUPPORT_DIR) + "/meshes/sphere_p25m.ply";
   meshes = createMeshFromPath<Mesh>(mesh_file);
   EXPECT_TRUE(meshes.size() == 1);
-  EXPECT_TRUE(meshes[0]->getTriangleCount() == 80);
-  EXPECT_TRUE(meshes[0]->getVerticeCount() == 42);
+  EXPECT_TRUE(meshes[0]->getFaceCount() == 80);
+  EXPECT_TRUE(meshes[0]->getVertexCount() == 42);
 
   mesh_file = std::string(TESSERACT_SUPPORT_DIR) + "/meshes/sphere_p25m.dae";
   meshes = createMeshFromPath<Mesh>(mesh_file);
   EXPECT_TRUE(meshes.size() == 2);
-  EXPECT_TRUE(meshes[0]->getTriangleCount() == 80);
-  EXPECT_TRUE(meshes[0]->getVerticeCount() == 42);
-  EXPECT_TRUE(meshes[1]->getTriangleCount() == 80);
-  EXPECT_TRUE(meshes[1]->getVerticeCount() == 42);
+  EXPECT_TRUE(meshes[0]->getFaceCount() == 80);
+  EXPECT_TRUE(meshes[0]->getVertexCount() == 42);
+  EXPECT_TRUE(meshes[1]->getFaceCount() == 80);
+  EXPECT_TRUE(meshes[1]->getVertexCount() == 42);
 
   mesh_file = std::string(TESSERACT_SUPPORT_DIR) + "/meshes/sphere_p25m.dae";
   meshes = createMeshFromPath<Mesh>(mesh_file, Eigen::Vector3d(1, 1, 1), false, true);
   EXPECT_TRUE(meshes.size() == 1);
-  EXPECT_TRUE(meshes[0]->getTriangleCount() == 2 * 80);
-  EXPECT_TRUE(meshes[0]->getVerticeCount() == 2 * 42);
+  EXPECT_TRUE(meshes[0]->getFaceCount() == 2 * 80);
+  EXPECT_TRUE(meshes[0]->getVertexCount() == 2 * 42);
 
   mesh_file = std::string(TESSERACT_SUPPORT_DIR) + "/meshes/box_2m.ply";
   meshes = createMeshFromPath<Mesh>(mesh_file, Eigen::Vector3d(1, 1, 1), true, true);
   EXPECT_TRUE(meshes.size() == 1);
-  EXPECT_TRUE(meshes[0]->getTriangleCount() == 12);
-  EXPECT_TRUE(meshes[0]->getVerticeCount() == 8);
+  EXPECT_TRUE(meshes[0]->getFaceCount() == 12);
+  EXPECT_TRUE(meshes[0]->getVertexCount() == 8);
 
   mesh_file = std::string(TESSERACT_SUPPORT_DIR) + "/meshes/box_2m.ply";
   meshes = createMeshFromPath<Mesh>(mesh_file, Eigen::Vector3d(1, 1, 1), true, true);
   EXPECT_TRUE(meshes.size() == 1);
-  EXPECT_TRUE(meshes[0]->getTriangleCount() == 12);
-  EXPECT_TRUE(meshes[0]->getVerticeCount() == 8);
+  EXPECT_TRUE(meshes[0]->getFaceCount() == 12);
+  EXPECT_TRUE(meshes[0]->getVertexCount() == 8);
 
   mesh_file = std::string(TESSERACT_SUPPORT_DIR) + "/meshes/box_2m.ply";
   std::vector<ConvexMesh::Ptr> convex_meshes =
       createMeshFromPath<ConvexMesh>(mesh_file, Eigen::Vector3d(1, 1, 1), false, false);
   EXPECT_TRUE(convex_meshes.size() == 1);
   EXPECT_TRUE(convex_meshes[0]->getFaceCount() == 6);
-  EXPECT_TRUE(convex_meshes[0]->getVerticeCount() == 8);
+  EXPECT_TRUE(convex_meshes[0]->getVertexCount() == 8);
 }
 
 #ifdef TESSERACT_ASSIMP_USE_PBRMATERIAL
@@ -312,14 +460,14 @@ TEST(TesseractGeometryUnit, LoadMeshWithMaterialGltf2Unit)  // NOLINT
   auto& mesh2 = meshes[2];
   auto& mesh3 = meshes[3];
 
-  EXPECT_EQ(mesh0->getTriangleCount(), 34);
-  EXPECT_EQ(mesh0->getVerticeCount(), 68);
-  EXPECT_EQ(mesh1->getTriangleCount(), 15);
-  EXPECT_EQ(mesh1->getVerticeCount(), 17);
-  EXPECT_EQ(mesh2->getTriangleCount(), 15);
-  EXPECT_EQ(mesh2->getVerticeCount(), 17);
-  EXPECT_EQ(mesh3->getTriangleCount(), 2);
-  EXPECT_EQ(mesh3->getVerticeCount(), 4);
+  EXPECT_EQ(mesh0->getFaceCount(), 34);
+  EXPECT_EQ(mesh0->getVertexCount(), 68);
+  EXPECT_EQ(mesh1->getFaceCount(), 15);
+  EXPECT_EQ(mesh1->getVertexCount(), 17);
+  EXPECT_EQ(mesh2->getFaceCount(), 15);
+  EXPECT_EQ(mesh2->getVertexCount(), 17);
+  EXPECT_EQ(mesh3->getFaceCount(), 2);
+  EXPECT_EQ(mesh3->getVertexCount(), 4);
 
   auto mesh0_normals = mesh0->getNormals();
   ASSERT_TRUE(mesh0_normals != nullptr);
